summaryrefslogtreecommitdiffhomepage
path: root/mixgtk/mixgtk_mixal.h
diff options
context:
space:
mode:
Diffstat (limited to 'mixgtk/mixgtk_mixal.h')
-rw-r--r--mixgtk/mixgtk_mixal.h23
1 files changed, 19 insertions, 4 deletions
diff --git a/mixgtk/mixgtk_mixal.h b/mixgtk/mixgtk_mixal.h
index 076603c..819819a 100644
--- a/mixgtk/mixgtk_mixal.h
+++ b/mixgtk/mixgtk_mixal.h
@@ -1,7 +1,7 @@
/* -*-c-*- ---------------- mixgtk_mixal.h :
* Declarations for functions displaying the mixal source file
* ------------------------------------------------------------------
- * Last change: Time-stamp: <01/03/09 23:57:14 jose>
+ * Last change: Time-stamp: <01/03/11 00:19:30 jose>
* ------------------------------------------------------------------
* Copyright (C) 2001 Free Software Foundation, Inc.
*
@@ -25,21 +25,36 @@
#ifndef MIXGTK_MIXAL_H
#define MIXGTK_MIXAL_H
+#include <gtk/gtk.h>
#include <mixlib/mix_vm.h>
/* initialise the mixal widgets */
extern gboolean
-mixgtk_mixal_init (const mix_vm_t *vm);
+mixgtk_mixal_init (mix_vm_t *vm);
/* load the corresponding mixal file */
extern void
mixgtk_mixal_load_file (void);
/* update the widgets */
extern void
mixgtk_mixal_update (void);
+/* breakpoints */
+extern void
+mixgtk_mixal_update_bp_at_address (guint addr);
+
+extern void
+mixgtk_mixal_update_bp_at_line (guint line);
+extern void
+mixgtk_mixal_update_bp_all (void);
+
+
+/* callbacks */
+extern void
+on_mixal_select_row (GtkWidget *w, gint row, gint col, GdkEventButton *e,
+ gpointer data);
#endif /* MIXGTK_MIXAL_H */
@@ -25,21 +25,36 @@
#include <mixlib/mix_vm.h>
-/* initialise the mixal widgets */
+/* initialise the mixal widget */
extern gboolean
@@ -25,21 +25,36 @@
extern void
mixgtk_mixal_load_file (void);
-/* update the widgets */
+/* update the widget */
extern void
mixgtk_mixal_update (void);